summaryrefslogtreecommitdiff
path: root/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h
diff options
context:
space:
mode:
Diffstat (limited to 'PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h')
-rw-r--r--PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h57
1 files changed, 25 insertions, 32 deletions
diff --git a/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h b/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h
index 82f4c40..f411112 100644
--- a/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h
+++ b/PluginRoutingInterfaceCAPI/src-gen/org/genivi/am/RoutingControlStubDefault.h
@@ -1,22 +1,11 @@
/*
-* This file was generated by the CommonAPI Generators.
-* Used org.genivi.commonapi.core 2.1.2.201309301424.
-* Used org.franca.core 0.8.9.201308271211.
+* This file was generated by the CommonAPI Generators.
+* Used org.genivi.commonapi.core 2.1.5.201312121915.
+* Used org.franca.core 0.8.11.201401091023.
*
-* Copyright (c) 2012 BMW
-*
-* \author Aleksandar Donchev, aleksander.donchev@partner.bmw.de BMW 2013
-*
-* \copyright
-* Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction,
-* including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
-* subject to the following conditions:
-* The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
-* THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-* For further information see http://www.genivi.org/.
-*
+* This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+* If a copy of the MPL was not distributed with this file, You can obtain one at
+* http://mozilla.org/MPL/2.0/.
*/
/**
* This class implements everything from Audiomanager -> RoutingAdapter
@@ -25,6 +14,7 @@
#ifndef ORG_GENIVI_AM_Routing_Control_STUB_DEFAULT_H_
#define ORG_GENIVI_AM_Routing_Control_STUB_DEFAULT_H_
+
#include <org/genivi/am/RoutingControlStub.h>
#include <sstream>
@@ -42,12 +32,14 @@ namespace am {
* that would be defined for this service, and/or if you do not need any non-default
* behaviour.
*/
-class RoutingControlStubDefault : public RoutingControlStub {
- public:
+class RoutingControlStubDefault : public virtual RoutingControlStub {
+public:
RoutingControlStubDefault();
RoutingControlStubRemoteEvent* initStubAdapter(const std::shared_ptr<RoutingControlStubAdapter>& stubAdapter);
+ const CommonAPI::Version& getInterfaceVersion(std::shared_ptr<CommonAPI::ClientId> clientId);
+
/**
* aborts an asynchronous action.
@@ -60,10 +52,10 @@ class RoutingControlStubDefault : public RoutingControlStub {
/**
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
* E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
*/
- virtual void asyncConnect(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_connectionID_t connectionID, am_sourceID_t sourceID, am_sinkID_t sinkID, am_ConnectionFormat_pe connectionFormat);
- virtual void asyncConnect(am_Handle_s handle, am_connectionID_t connectionID, am_sourceID_t sourceID, am_sinkID_t sinkID, am_ConnectionFormat_pe connectionFormat);
+ virtual void asyncConnect(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_connectionID_t connectionID, am_sourceID_t sourceID, am_sinkID_t sinkID, am_CustomConnectionFormat_t connectionFormat);
+ virtual void asyncConnect(am_Handle_s handle, am_connectionID_t connectionID, am_sourceID_t sourceID, am_sinkID_t sinkID, am_CustomConnectionFormat_t connectionFormat);
/**
* disconnect a connection with given connectionID
@@ -80,8 +72,8 @@ class RoutingControlStubDefault : public RoutingControlStub {
(at)return E_OK on success, E_UNKNOWN on error,
* E_OUT_OF_RANGE if new volume is out of range
*/
- virtual void asyncSetSinkVolume(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_sinkID_t sinkID, am_volume_t volume, am_RampType_pe ramp, am_time_t time);
- virtual void asyncSetSinkVolume(am_Handle_s handle, am_sinkID_t sinkID, am_volume_t volume, am_RampType_pe ramp, am_time_t time);
+ virtual void asyncSetSinkVolume(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_sinkID_t sinkID, am_volume_t volume, am_CustomRampType_t ramp, am_time_t time);
+ virtual void asyncSetSinkVolume(am_Handle_s handle, am_sinkID_t sinkID, am_volume_t volume, am_CustomRampType_t ramp, am_time_t time);
/**
* sets the volume of a source. This method is used to set the volume of a sink.
@@ -92,8 +84,8 @@ class RoutingControlStubDefault : public RoutingControlStub {
* range.
triggers the acknowledge ackSourceVolumeChange
*/
- virtual void asyncSetSourceVolume(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_sourceID_t sourceID, am_volume_t volume, am_RampType_pe ramp, am_time_t time);
- virtual void asyncSetSourceVolume(am_Handle_s handle, am_sourceID_t sourceID, am_volume_t volume, am_RampType_pe ramp, am_time_t time);
+ virtual void asyncSetSourceVolume(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_sourceID_t sourceID, am_volume_t volume, am_CustomRampType_t ramp, am_time_t time);
+ virtual void asyncSetSourceVolume(am_Handle_s handle, am_sourceID_t sourceID, am_volume_t volume, am_CustomRampType_t ramp, am_time_t time);
/**
* This function is used to set the source state of a particular
@@ -140,8 +132,8 @@ class RoutingControlStubDefault : public RoutingControlStub {
(at)return E_OK on success, E_UNKNOWN on
* error
*/
- virtual void asyncCrossFade(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_crossfaderID_t crossfaderID, am_HotSink_e hotSink, am_RampType_pe rampType, am_time_t time);
- virtual void asyncCrossFade(am_Handle_s handle, am_crossfaderID_t crossfaderID, am_HotSink_e hotSink, am_RampType_pe rampType, am_time_t time);
+ virtual void asyncCrossFade(const std::shared_ptr<CommonAPI::ClientId> clientId, am_Handle_s handle, am_crossfaderID_t crossfaderID, am_HotSink_e hotSink, am_CustomRampType_t rampType, am_time_t time);
+ virtual void asyncCrossFade(am_Handle_s handle, am_crossfaderID_t crossfaderID, am_HotSink_e hotSink, am_CustomRampType_t rampType, am_time_t time);
/**
* this function is used for early and late audio functions to set the domain
@@ -161,11 +153,10 @@ class RoutingControlStubDefault : public RoutingControlStub {
virtual void asyncSetSourceNotificationConfiguration(am_Handle_s handle, am_sourceID_t sourceID, am_NotificationConfiguration_s notificationConfiguration);
-
- protected:
- std::shared_ptr<RoutingControlStubAdapter> stubAdapter_;
- private:
+
+protected:
+private:
class RemoteEventHandler: public RoutingControlStubRemoteEvent {
public:
RemoteEventHandler(RoutingControlStubDefault* defaultStub);
@@ -177,6 +168,8 @@ class RoutingControlStubDefault : public RoutingControlStub {
RemoteEventHandler remoteEventHandler_;
+
+ CommonAPI::Version interfaceVersion_;
};
} // namespace am
@@ -60,10 +52,10 @@ class RoutingControlStubDefault : public RoutingControlStub {
* connects a source to a sink
(at)return E_OK on success, E_UNKNOWN on error,
- * E_WRONG_FORMAT in case am_ConnectionFormat_e does not match
+ * E_WRONG_FORMAT in case am_CustomConnectionFormat_t does not match
*/